==> owncloud-5.0.9.tgz: owncloud/apps/bookmarks/l10n/pl.php <==
<?php $TRANSLATIONS = array(
"No file provided for import" => "Nie wybrano plików do importu",
"Unsupported file type for import" => "Nieobsługiwany typ pliku do importu",
"Bookmarks" => "Zakładki",
"Tags" => "Tagi",
"Filter by tag" => "Filtruj po tagach",
"Edit bookmark" => "Edytuj zakładkę",
"Are you sure you want to remove this tag from every entry?" => "Czy na pewno chcesz usunąć ten tag na każdym wejściu?",
"Warning" => "Ostrzeżenie",
"Import error" => "Błąd importu",
"Import completed successfully." => "Importowanie zostało pomyślnie ukończone.",
"Uploading..." => "Wgrywanie....",
"Bookm." => "Zakładka",
"Add a bookmark" => "Dodaj zakładkę",
"Close" => "Zamknij",
"The title of the page" => "Tytuł strony",
"The address of the page" => "Adres strony",
"Description of the page" => "Opis strony",
"Save" => "Zapisz",
"Delete" => "Usuń",
"Edit" => "Edytuj",
"Cancel" => "Anuluj",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Przeciągnij to do ulubionych przeglądarki i kliknij go, gdy użytkownik chce szybko dodać zakładkę strony sieci Web:",
"Read later" => "Czytaj później",
"Address" => "Adres",
"Add" => "Dodaj",
"Related Tags" => "Powiązane Tagi",
"Settings" => "Ustawienia",
"You have no bookmarks" => "Nie masz żadnych zakładek",
"You can also try to import a bookmark file" => "Można również spróbować zaimportować plik zakładki",
"Bookmarklet" => "Zakładka",
"Export & Import" => "Eksportuj i Importuj",
"Export" => "Export",
"Import" => "Import"
);

==> owncloud-7.0.4.tgz: owncloud/apps/bookmarks/l10n/pl.php <==
<?php
$TRANSLATIONS = array(
"No file provided for import" => "Nie wybrano plików do importu",
"Unsupported file type for import" => "Nieobsługiwany typ pliku do importu",
"Bookmarks" => "Zakładki",
"Tags" => "Tagi",
"Filter by tag" => "Filtruj po tagach",
"Edit bookmark" => "Edytuj zakładkę",
"Are you sure you want to remove this tag from every entry?" => "Czy na pewno chcesz usunąć ten tag z każdego wpisu?",
"Warning" => "Ostrzeżenie",
"Import error" => "Błąd importu",
"Import completed successfully." => "Importowanie zostało pomyślnie ukończone.",
"Uploading..." => "Wgrywanie....",
"Bookm." => "Zakładka",
"Add a bookmark" => "Dodaj zakładkę",
"Close" => "Zamknij",
"The title of the page" => "Tytuł strony",
"The address of the page" => "Adres strony",
"Description of the page" => "Opis strony",
"Save" => "Zapisz",
"Delete" => "Usuń",
"Edit" => "Edytuj",
"Cancel" => "Anuluj",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Przeciągnij to do zakładek w przeglądarce i kliknij, jeśli chcesz szybko dodać stronę do zakładek:",
"Add to ownCloud" => "Dodaj do ownCloud",
"Address" => "Adres",
"Add" => "Dodaj",
"Related Tags" => "Powiązane Tagi",
"Settings" => "Ustawienia",
"You have no bookmarks" => "Nie masz żadnych zakładek",
"You can also try to import a bookmark file" => "Można również spróbować zaimportować plik zakładki",
"Bookmarklet" => "Zakładka",
"Export & Import" => "Eksportuj i Importuj",
"Export" => "Export",
"Import" => "Import"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
